.\" -*- nroff -*- generated from .Rd format
.BG
.FN coords.aniso
.TL
(Geometric) anisotropy correction
.DN
Transform or back-transform a set of coordinates according to
the parameters defining the geometric anisotropy.
.CS

coords.aniso(coords, aniso.pars, reverse = FALSE)

.RA
.AG coords
an n x 2 matrix with the coordinates
to be transformed.  
.AG aniso.pars
a vector with two elements: the anisotropy
angle and the anisotropy ratio necessarily in this order.
See section DETAILS below for the description of these elemets.  
.AG reverse
Defaults to `FALSE'. If `TRUE' the reverse
transformation is performed.  
.RT
An n x 2 matrix with the transformed coordinates.
.SH REFERENCES
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>

.EX
par.mf <- par()$mfrow
par(mfrow=c(3,2))
par(mar=c(2.5,0,0,0))
par(mgp=c(2,.5,0))
par(pty="s")
## Defining a set of coordinates
coords <- expand.grid(seq(-1, 1, l=3), seq(-1, 1, l=5))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coords)
## Transforming coordinates according to some anisotropy parameters
coordsA <- coords.aniso(coords, aniso.pars=c(0, 2))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coordsA)
##
coordsB <- coords.aniso(coords, aniso.pars=c(pi/2, 2))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coordsB)
##
coordsC <- coords.aniso(coords, aniso.pars=c(pi/4, 2))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coordsC)
##
coordsD <- coords.aniso(coords, aniso.pars=c(3*pi/4, 2))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coordsD)
##
coordsE <- coords.aniso(coords, aniso.pars=c(0, 5))
plot(c(-1.5, 1.5), c(-1.5, 1.5), xlab="", ylab="", type="n")
points(coordsE)
##
par(mfrow=par.mf)
.KW spatial
.WR
