.\" -*- nroff -*- generated from .Rd format
.BG
.FN cov.spatial
.TL
Computes Covariances from Given Distances
.DN
Computes the covariances for pairs of points, given their separation distance.
Includes options for several correlation functions.
Can be see as a change of metric, from the Euclidean distances to
covariances.
.CS

cov.spatial(obj, cov.model=c("exponential", "matern", "gaussian",
            "spherical", "circular", "cubic", "wave",
            "powered.exponential", "cauchy", 
            "gneiting", "gneiting.matern", "pure.nugget"),
            cov.pars=stop("no cov.pars argument provided"), kappa)

.RA
.AG obj
an object (vector or matrix) with distances.
.AG cov.model
a string indicating the type of the correlation
function.
See the DETAILS below for options and expressions of the correlation functions.
.AG cov.pars
a vector with 2 elements or an ns x 2 matrix with
the covariance parameters. The first element (if a vector) or first column (if a matrix) is the variance parameter sigma^2. The
second element or column is the correlation function parameter
phi. If a matrix is provided, each row corresponds to
the parameters of one spatial structure. Models with several structures
are sometimes called nested models in the geostatistical literature.
.AG kappa
additional parameter needed for some of the correlation
functions, namely: `"matern"', `"powered.exponential"', `"gneiting"' and
`"gneiting.matern"'.
.RT
The function returns covariances values for the given distances.
The type of object is the same as the type of the object provided in the
argument `obj', typically a vector, matrix or array.
Note
This is an auxiliary function called by a number of other
functions in the package..SH REFERENCES
Ribeiro, P.J. Jr. and Diggle, P.J. (1999) {\tt geoR/geoS}: a geostatistical package/library for R/S-PLUS. Tech. Report ST-99-09, Depto
Maths and Stats, Lancaster University.
.br
Available at: 
<URL: http://www.maths.lancs.ac.uk/~ribeiro/publications.html>
.IP "" 
Further information about `geoR/geoS' can be found at:
.br
<URL: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html>
.SA
`matern', `varcov.spatial', `likfit', `krige.bayes', `krige.conv', `grf'.
.EX
#
# Variogram models with the same "practical" range:
#
xval <- seq(0,1,l=101)
vexp <- cov.spatial(xval, cov.pars=c(1, .2))
vsph <- cov.spatial(xval, cov.pars=c(1, .60), cov.model="sph")
vgau <- cov.spatial(xval, cov.pars=c(1, .60/sqrt(3)),
                    cov.model="gau")
plot(0:1, 0:1, type="n", xlab="distance",
     ylab=expression(gamma(h)),
     main="variograms with equivalent \"practical range\"")
lines(xval, (1-vexp))
lines(xval, (1-vsph), lty=2)
lines(xval, (1-vgau), lwd=2)
legend(0.5,.3, c("exponential", "spherical", "gaussian"),
       lty=c(1,2,1), lwd=c(1,1,2))
#
# Matern models with equivalent "practical range"
# and varying smoothness parameter
#
dval <- seq(0,1,l=101)
mat.5 <- cov.spatial(dval, cov.pars = c(1, 0.25), kappa = 0.5)
mat1 <-  cov.spatial(dval, cov.pars = c(1, 0.188), kappa = 1,
                     cov.model="mat")
mat2 <-  cov.spatial(dval, cov.pars = c(1, 0.14), kappa = 2,
                     cov.model="mat")
mat3 <-  cov.spatial(dval, cov.pars = c(1, 0.117), kappa = 3,
                     cov.model="mat")
plot(0:1, 0:1, type="n", xlab="distance",
     ylab=expression(gamma(h)),
     main="models with equivalent \"practical\" range")
lines(dval, 1-mat.5, lty=2)
lines(dval, 1-mat1)
lines(dval, 1-mat2, lwd=2, lty=2)
lines(dval, 1-mat3, lwd=2)
legend(0.5,.3, c(expression(paste(kappa == 0.5, "  and  ",
       phi == 0.250)),
expression(paste(kappa == 1, "  and  ", phi == 0.188)),
expression(paste(kappa == 2, "  and  ", phi == 0.140)),
expression(paste(kappa == 3, "  and  ", phi == 0.117))),
lty=c(2,1,2,1), lwd=c(1,1,2,2))

.KW spatial
.WR
